@@ -8,7 +8,7 @@ package Sumu::Perl::Modules;
 
 =head1 VERSION
 
-version 0.4.4
+version 0.4.5
 
 =head2 SYNOPSIS
 
@@ -22,14 +22,14 @@ version 0.4.4
 
         my ($mod, $dirs, $files) = $modules->_dirs(current_user => $current_user, module => "$module");
 
-        my ($mod, $out) = $modules->_doc( module => $module );
+        my ($mod, $out) = $modules->_doc( module => "$module" );
 
 
 =head2 DESCRIPTION
 
     List all installed Perl Modules on your system
 
-=head2 For Developer Only
+=head2 For Developer
 
     Being tested in:
 
@@ -73,13 +73,13 @@ use warnings;
 
 =head2 our VERSION
 
-    our $VERSION = '0.4.4'
+    our $VERSION = '0.4.5'
 
     This version number is updated automatically!
 
 =cut
 
-our $VERSION = '0.4.4';
+our $VERSION = '0.4.5';
 
 
 =head2 Internals
@@ -98,6 +98,8 @@ our @EXPORT_OK = qw(
     _extutils 
     _dirs 
     _doc
+    _inc
+    _inc_dir
 ); 
 
 =head2 sub NAME
@@ -149,7 +151,7 @@ use Pod::Html;
 
     Usage:
 
-        my $modules_list = $modules->_extutils( module => $"module" );
+        my $modules_list = $modules->_extutils( module => "$module" );
 
 =cut
 
@@ -273,7 +275,7 @@ sub _dirs  {
             as text with a line break (<br>) appended to end of each line
     Usage:
 
-        my ($total_lines, $out) = $modules->_doc( module => "$module" );
+        my ($total_lines, $out, $error) = $modules->_doc( module => "$module" );
 
 =cut
 
@@ -288,34 +290,35 @@ sub _doc {
     my $out;
     #
     my $total_lines;
-
+    #
+    my $error;
     #
     my $module = $in{module};
         chomp $module;
 
     $module =~ s!\\!\/!g;
+
+    if ( -f "$module" ) {
+        if ( open( my $FILE, "<", "$module" ) ) {
+            while ( my $line = <$FILE> ) {
+                #
+                $total_lines++ if $line;
+                #
+                $line =~ s!\<!&lt;!g;
+                $line =~ s!\>!&gt;!g;
+                #
+                $out .= qq{$line<br>};
+            }
+            close $FILE;
+        } else {
+            $error .= qq{Unable to open module};
+        }
+    } else {
+        $error = qq{Not a file or incorrect file path};
+    }
     
-    my @doc = `perldoc "$module"`;
 
-    $total_lines = scalar @doc;
-
-    for (@doc) {
-        $_ =~ s!\<!&lt;!g;
-        $_ =~ s!\>!&gt;!g;
-        $out .= qq{$_<br>};
-    }
-
-    if ($total_lines < 9 ) {
-        @doc = `pod2html "$module"`;
-    }
-
-    for (@doc) {
-        $out .= qq{$_ };
-    }
-
-    $total_lines = scalar @doc;
-
-    return ($total_lines, $out);
+    return ($total_lines, $out, $error);
 
     #
 
@@ -335,6 +338,10 @@ sub _doc {
 
                 see sub _inc_dir 
 
+    Usage:
+
+        my $out = $modules->_inc( module = "$module" );
+
 =cut
 
 sub _inc {
